==> maxdb-7.5.00_7.5.00.12.orig.tar.gz: maxdb-7.5.00-7.5.00.12.orig/MaxDB_ORG/sys/src/ls/hls21.h <==
/*! 
  -----------------------------------------------------------------------------
 
  module: hls21.h
 
  -----------------------------------------------------------------------------
 
  responsible:  SteffenS

  special area: Replication Manager
 
  description:  Fastload execution (definitions)

  version:      7.4.

  -----------------------------------------------------------------------------
 
  copyright:    (c) 1999-2004 SAP AG-2001
 
  -----------------------------------------------------------------------------



    ========== licence begin  GPL
    Copyright (c) 1999-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end



*/

#ifndef HLS21
#define HLS21

#include "gls00.h"

#define BEGINLOAD_CMD_LS21          _T("BEGINLOAD %s")
#define BEGINLOAD_W_STAMP_CMD_LS21  _T("BEGINLOAD %s WITH STAMP")
#define ENDLOAD_CMD_LS21            _T("ENDLOAD %s")


const tsp00_Int4 lStmtLength_ls21 = 4 * KNL_IDENTIFIER_SIZE;

/*!
  -----------------------------------------------------------------------------

  function:     ls21ExecFastload
  -----------------------------------------------------------------------------

  description:  Processes a fastload command.

  arguments:    pFLCmd     [IN]  - fastload command structure with user info
                pDBInfo    [IN]  - structure with info on db and running session
                pszErrText [OUT] - error text

  returnvalue:  errOK_els00 - no error
                errors from processing 
  -----------------------------------------------------------------------------
*/
int
ls21ExecFastload(tls00_FloadCmd *pFLCmd, tls00_DBInfo *pDBInfo, tsp00_Addr pszErrText);

#endif /*HLS21*/

==> maxdb-7.5.00_7.5.00.24.orig.tar.gz: maxdb-7.5.00-7.5.00.24.orig/MaxDB_ORG/sys/src/ls/hls21.h <==
/*! 
  -----------------------------------------------------------------------------
 
  module: hls21.h
 
  -----------------------------------------------------------------------------
 
  responsible:  SteffenS,d033893

  special area: Loader
 
  description:  Fastload execution (definitions)

  version:      7.5.

  -----------------------------------------------------------------------------
 
  Copyright (c) 1999-2004 SAP AG-2001
 
  -----------------------------------------------------------------------------




    ========== licence begin  GPL
    Copyright (c) 1999-2004 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end



*/

#ifndef HLS21
#define HLS21

#include "gls00.h"
#include "hls31_odbc_Result.h"

#define BEGINLOAD_CMD_LS21          _T("BEGINLOAD %s")
#define BEGINLOAD_W_STAMP_CMD_LS21  _T("BEGINLOAD %s WITH STAMP")
#define ENDLOAD_CMD_LS21            _T("ENDLOAD %s")


const tsp00_Int4 lStmtLength_ls21 = 4 * KNL_IDENTIFIER_SIZE;

/*!
  -----------------------------------------------------------------------------

  function:     ls21ExecFastload
  -----------------------------------------------------------------------------

  description:  Processes a fastload command.

  arguments:    pTransformationCmd     [IN]  - fastload command structure with user info
                pDBInfo    [IN]  - structure with info on db and running session
                pszErrText [OUT] - error text

  returnvalue:  errOK_els00 - no error
                errors from processing 
  -----------------------------------------------------------------------------
*/
int
ls21ExecFastload(MetaDataDef  *pMetaDataDef,
				 tls00_DBInfo *pDBInfo, 
				 tsp00_Addr    ErrText);

#endif /*HLS21*/
